# Use FTDI to write  Arduino Pro Mini

## BOM
-  [FTDI USBシリアル変換アダプター Rev.2](https://www.switch-science.com/catalog/2782/) @1,080
![](https://d2air1d4eqhwg2.cloudfront.net/images/2782/500x500/60d8009c-8dda-4d13-9028-8a261af91dfb.jpg) 

-  [HiLetgo® 3個セット pro mini ATMEGA328P 5V 16MHz Arduino PRO miniと互換 [並行輸入品]](https://www.amazon.co.jp/gp/product/B013QV2EQM/ref=ppx_yo_dt_b_asin_title_o01_s00?ie=UTF8&psc=1) @1,060/3
![](https://images-na.ssl-images-amazon.com/images/I/71VgtPHpYBL._SL1100_.jpg)


## Connection
![](images/arduino-pro-mini/ftdf-arduino-pro-mini.jpg)

![](images/arduino-pro-mini/pro-mini-ftdi-pins.jpg)

## Arduino IDE
### Tool
![](images/arduino-pro-mini/arduino-IDE-tool.png)
### code
```
void setup() {
  Serial.begin(9600);
}

void loop() {
  Serial.print("*****");
  delay(200);
  Serial.print("sample");
  delay(500);
  Serial.println("*****");
  delay(200);
  Serial.println("こんにちは");
  delay(200);
  Serial.println('a');
  delay(200);
  Serial.println(1);
  delay(200);
}
```
![](images/arduino-pro-mini/arduino-IDE-serialmonitor.png)

# Use Arduino_UNO_ISP to write Arduino Pro Mini
## Making Arduino UNO A Programmer
- Connect Arduino Uno to PC by USB
- Select Board: Arduino UNO
![](images/arduino-pro-mini/arduino-IDE-arduinoUNO-board.png)
- Code: ArduinoISP from sample sketch
![](images/arduino-pro-mini/arduino-IDE-arduinoISP.png)
- Write the sketch

## Write a sketch to Arduino Pro Mini from ArduinoISP
- Connect Arduino Uno to PC by USB
- No need to connect Arduino Pro Mini to PC
- Connect Arduino Uno(ISP) to Arduino Pro Mini
- 10µF Capacitor connected to RESET and GND
  - ref.[Arduino as ISP and Arduino Bootloaders 
](https://www.arduino.cc/en/tutorial/arduinoISP)  
![](images/arduino-pro-mini/fritzing-isp.png)
![](images/arduino-pro-mini/fritzing-cable.png)
- Open a sketch for Arduino Pro Mini 
- Select programmer : Arduino as ISP
- ![](images/arduino-pro-mini/arduino-IDE-arduino-as-ISP.png)
- Write the sketch from programmer
- ![](images/arduino-pro-mini/arduino-IDE-write-from-arduinoisp.png)


# Write a sketch to ATmwga328P from ArduinoISP

- ref. [Arduino for other Chips](https://playground.arduino.cc/Main/ArduinoOnOtherAtmelChips/)
- [MiniCore](https://github.com/MCUdude/MiniCore)
  - ATmega328/A/P/PA/PB, ATmega168/A/P/PA/PB, ATmega88/A/P/PA/PB, ATmega48/A/P/PA/PB, ATmega8/A
  - Arduino IDE > menu > Preferences > Additional Boards Manager > https://mcudude.github.io/MiniCore/package_MCUdude_MiniCore_index.json
  - Minimal setup
  - DIP-28 package
    - ![](images/arduino-pro-mini/DIP-28-package.jpeg)
     - ![](images/arduino-pro-mini/DIP-28-package-minimal.png)
  - TQFP-32-SMD-package 
    - ![](images/arduino-pro-mini/TQFP-32-SMD-package.jpeg)
    - ![](images/arduino-pro-mini/TQFP-32-SMD-package-minimal.png)
  - TQFP-32-SMD-PB- package 
    - ![](images/arduino-pro-mini/TQFP-32-SMD-packagePB.jpeg)
    - ![](images/arduino-pro-mini/TQFP-32-SMD-package-minimaiPB.png)
  
## Connection DIP-28
### ArduuinoUNO-ISP to 328P
![](images/arduino-pro-mini/fritzing-Uno-328P-minimal.png)
```
void setup() {
  pinMode(9, OUTPUT);
}

void loop() {
  digitalWrite(9, HIGH);
  delay(1000);
  digitalWrite(9,LOW);
  delay(2000);

} 
```
![](images/arduino-pro-mini/fritzing-Uno-328P-blink.png)


## Capaciter

|表記	|ピコ（p)	|ナノ(n)	|マイクロ(u)|
|---|---|---|---|
|10	|10pF|||	　	　
|101	|100pF|||	　	　
|102	|1000pF	|1nF |0.001uF|
|103	|10000pF	|10nF	|0.01uF|
|104	|100000pF	|100nF |0.1uF|
|105	|1000000pF|1000nF	|1uF|

100nF=100x1000pF=10x10^1x10^3pF=10x10^4->104


## Burning the Bootloader

[From Arduino to a Microcontroller on a Breadboard](https://www.arduino.cc/en/Tutorial/ArduinoToBreadboard)

FTDI driver
```
$ kextstat | grep -i ftdi
```
